import { drizzle } from 'drizzle-orm/mysql2';
import { sql } from 'drizzle-orm';
import mysql from 'mysql2/promise';
import fastifyPlugin from 'fastify-plugin';
async function database(fastify, options) {
    fastify.log.warn('Register Database Plugin!');
    const config = fastify.config;
    // 配置数据库
    const pool = await mysql.createPool({
        host: config.db.host,
        port: config.db.port,
        user: config.db.user,
        password: config.db.password,
        database: config.db.database,
        // ssl: config.db.ssl,
        waitForConnections: true,
        connectionLimit: 10,
        queueLimit: 0,
        // 启用此选项后，MySQL驱动程序将支持大数字（big numbers），这对于存储和处理 bigint 类型的数据尤为重要。
        // 如果不启用此选项，MySQL驱动程序可能无法正确处理超过 JavaScript 数字精度范围的大数值，导致数据精度丢失。
        supportBigNumbers: true,

        // 启用此选项后，MySQL驱动程序将在接收 bigint 或其他大数值时，将其作为字符串返回，而不是作为JavaScript数字。
        // 这种处理方式可以避免JavaScript本身的数值精度限制问题，确保大数值在应用程序中保持精确。
        bigNumberStrings: true,
    });
    // 暴露数据库
    const db = drizzle(pool);
    // 新增获取所有表名方法
    const [result] = await db.execute(sql`SHOW TABLES`);
    const tableList = result.map(row => Object.values(row)[0]);
    db.tableList = tableList;
    fastify.decorate('db', db);

    // 读取数据库基本信息
    fastify.log.warn('Register Database Complete! => DATABASE TABLES: ' + fastify.db.tableList.length);
}
export default fastifyPlugin(database);
