import fastifyPlugin from 'fastify-plugin';
function errorHandler(fastify) {
    fastify.setErrorHandler((error, request, reply) => {
        // 记录原始错误
        fastify.log.error(`[ErrorHandler] ${error.message}`, error);
        // 保留AJV验证错误处理
        if (error.validation) {
            console.log(error)
            const bodyError = error.validation.find(e => 
                e.keyword === 'type' || 
                e.keyword === 'required' && e.validationContext == 'body'
            );
            
            if (bodyError) {
                return reply.code(400).send({
                    error: '请求体不能为空，请提供有效的JSON数据',
                    details: error.validation
                });
            }
            return reply.code(400).send({
                error: error.message,
                details: error.validation
            });
        }

        // 使用sensible的HTTP错误处理
        if (error.statusCode && error.statusCode >= 400) {
            return reply
                .code(error.statusCode)
                .send({ 
                    code: error.code || 'HTTP_ERROR',
                    error: error.message 
                });
        }

        // 处理Fastify自动生成的404错误
        if (error.code === 'FST_ERR_NOT_FOUND') {
            return reply.code(404).send({
                code: 'ROUTE_NOT_FOUND',
                error: `路由 ${request.url} 不存在`
            });
        }
        // 最终未处理错误（生产环境隐藏细节）
        const isProduction = process.env.NODE_ENV === 'production';
        reply.code(500).send({
            code: 'SERVER_ERROR',
            error: isProduction ? '服务器内部错误' : error.message,
            ...(!isProduction && { stack: error.stack })
        });
    });
}
export default fastifyPlugin(errorHandler);