import { isTrim } from "#utils/ajv/method";
import { is } from "drizzle-orm";

// 原子schema定义
export const username = {
    type: 'string',
    minLength: 4,
    maxLength: 20,
    pattern: '^[a-z][a-z0-9_]*$',
    isLowerCase: true,
    isTrim: true,
    errorMessage: {
        minLength: '用户名至少需要4个字符',
        maxLength: '用户名不能超过20个字符',
        pattern: '必须全部小写，且只能包含字母、数字和下划线，并以字母开头'
    }
};

export const email = {
    type: 'string',
    format: 'email',
    maxLength: 128,
    errorMessage: {
        format: '邮箱格式不正确',
        maxLength: '邮箱不能超过128个字符'
    }
};

export const password = {
    type: 'string',
    minLength: 8,
    maxLength: 128,
    pattern: '^(?=.*[a-z])(?=.*[A-Z])(?=.*\\d)(?=.*[@$!%*?&])[A-Za-z\\d@$!%*?&]+$',
    errorMessage: {
        minLength: '密码长度至少8位',
        maxLength: '密码不能超过128个字符',
        pattern: '必须包含至少一个小写字母、一个大写字母、一个数字和一个特殊字符'
    }
};