import config from '#config/index';
export default {
    // 日志级别顺序（从高到低）：
    // fatal(致命) > error(错误) > warn(警告) > info(信息) > debug(调试) > trace(追踪)
    // 高级别日志会包含低级别日志（设置warn会包含error和fatal）
    level: config.logger.level,
    transport: {
        // 修正为独立的多传输配置
        targets: [
            config.logger.console && {
                level: config.logger.level,
                target: 'pino-pretty',
                options: {
                    colorize: true,
                    translateTime: 'yyyy-mm-dd HH:MM:ss',
                    ignore: 'pid,hostname,reqId,res,responseTime',
                    // 可用字段列表：
                    // - pid: 进程ID
                    // - hostname: 主机名
                    // - level: 日志级别（不建议忽略）
                    // - time: 时间戳（需配合translateTime使用）
                    // - msg/message: 日志消息（必须保留）
                    // - module: 模块名称（自定义字段）
                    // - name: 日志名称
                    // - v: pino版本号
                    // - reqId: 请求ID
                    // - res: 响应对象
                    // - req: 请求对象
                    // - responseTime: 响应时间
                    // - 支持通配符如 'req*'（忽略所有 req 开头字段）
                },
            },
            {
                target: 'pino/file',
                options: {
                    destination: config.logger.filePath, // 文件路径从配置读取
                    mkdir: true,
                    ignore: 'pid,hostname',
                },
            },
        ],
    },
};
